@@ -10,14 +10,14 @@
 #include <qlabel.h>
 #include <qpushbutton.h>
 #include <qradiobutton.h>
-#include <qspinbox.h>
+#include "mspinbox.h"
 
 class Align : public QDialog
 { 
     Q_OBJECT
 
 public:
-    Align( QWidget* parent, int anz, int ein, float umr);
+    Align( QWidget* parent, int anz, int ein);
     ~Align();
 
     QButtonGroup* ButtonGroup1_2;
@@ -27,11 +27,11 @@ public:
     QLabel* TextLabelD;
     QLabel* TextLabelD2;
     QComboBox* VartV;
-    QSpinBox* AVert;
+    MSpinBox* AVert;
     QButtonGroup* ButtonGroup1;
     QRadioButton* VerteilenH;
     QRadioButton* NichtsH;
-    QSpinBox* AHor;
+    MSpinBox* AHor;
     QComboBox* VartH;
     QLabel* TextLabel1;
     QPushButton* OKbutton;
@@ -40,9 +40,9 @@ public:
     QRadioButton* CheckV;
     QRadioButton* CheckH;
     int Anzahl;
-    float Umrech;
 
 public slots:
+		virtual void setVa();
     virtual void DistHoriz();
     virtual void DistVert();
     virtual void slotApplyDiag();
@@ -51,6 +51,8 @@ signals:
 		void ApplyDist(bool, bool, bool, bool, float, float, int, int);
 
 protected:
+		void keyPressEvent(QKeyEvent *k);
+		void keyReleaseEvent(QKeyEvent *k);
     QVBoxLayout* AlignLayout;
     QHBoxLayout* Layout4;
     QGridLayout* ButtonGroup1Layout;
