@@ -29,7 +29,7 @@ FontPrefs::FontPrefs( QWidget* parent,  SCFonts &flist)
 			QCheckBox *cp2 = new QCheckBox(this, "ps");
     	cp2->setText(tr("Postscript"));
     	cp2->setChecked(it.current()->EmbedPS);
-    	cp2->setBackgroundColor(white);
+    	cp2->setEraseColor(white);
     	FlagsPS.append(cp2);
     	Table1->setCellWidget(a, 2, cp2);
     	Table1->setText(a, 3, it.current()->Datei);
@@ -67,15 +67,13 @@ FontPrefs::FontPrefs( QWidget* parent,  SCFonts &flist)
     Layout2->setMargin( 0 );
     QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
     Layout2->addItem( spacer );
+    PushButton1 = new QPushButton( this, "PushButton1" );
+    PushButton1->setText( tr( "OK" ) );
+    Layout2->addWidget( PushButton1 );
     PushButton1_2 = new QPushButton( this, "PushButton1_2" );
-    PushButton1_2->setMinimumSize( QSize( 90, 30 ) );
     PushButton1_2->setText( tr( "Cancel" ) );
     PushButton1_2->setDefault( TRUE );
     Layout2->addWidget( PushButton1_2 );
-    PushButton1 = new QPushButton( this, "PushButton1" );
-    PushButton1->setMinimumSize( QSize( 90, 30 ) );
-    PushButton1->setText( tr( "OK" ) );
-    Layout2->addWidget( PushButton1 );
     FontPrefsLayout->addLayout( Layout2 );
     resize( 590, 255 );
 //    setMinimumSize( sizeHint() );
