@@ -45,7 +45,7 @@ About::About( QWidget* parent )
                         "<tr><td><b>" + tr("Documentation:") + "</b></td><td></td></tr>" +
                         "<tr><td>Thomas Zastrow</td><td>webmaster@thomas-zastrow.de</td></tr>" +
                         "<tr><td>Yves Ceccone</td><td>yves@yeccoe.org</td></tr>" +
-                        "<tr><td>Peter Linnell</td><td>netscribe@mediaone.net</td></tr></table>");
+                        "<tr><td>Peter Linnell</td><td>netscribe@attbi.com</td></tr></table>");
     TextView1->setTextFormat( QTextView::RichText );
     tabLayout->addWidget( TextView1 );
     TabWidget2->insertTab( tab_2, tr( "Authors" ) );
@@ -76,7 +76,13 @@ About::About( QWidget* parent )
                         "<tr><td><b>" + tr("Galician:") + "</b></td><td> </td></tr>" +
                         "<tr><td>Manuel Anxo Rei</td><td>manxopar@avogaciagalega.org</td></tr>" +
                         "<tr><td> </td><td> </td></tr>" +
-                        "<tr><td><b>" + tr("Slovak:") + "</b></td><td> </td></tr>" +
+                        "<tr><td><b>" + tr("Turkish:") + "</b></td><td> </td></tr>" +
+                        "<tr><td>Erkan Kaplan</td><td>Selamsana@uni.de</td></tr>" +
+                        "<tr><td> </td><td> </td></tr>" +
+                        "<tr><td><b>" + tr("Lithuanian:") + "</b></td><td> </td></tr>" +
+                        "<tr><td>Aivaras Kirejevas</td><td>kiras@mail.lt</td></tr>" +
+                        "<tr><td> </td><td> </td></tr>" +
+                        "<tr><td><b>" + tr("Slovak:") + "</b></td><td></td></tr>" +
                         "<tr><td>Zdenko Podobn</td><td>zdpo@mailbox.sk</td></tr></table>");
     TextView2->setTextFormat( QTextView::RichText );
     tabLayout_2->addWidget( TextView2 );
