@@ -50,17 +50,24 @@ public:
 private:
 	QString FToStr(float c);
 	QString IToStr(int c);
+	QString SetClipPath(PageItem *ite);
+	QString SetFarbe(QString farbe, int Shade);
+	QString setTextSt(PageItem *ite, uint PNr);
 	void PutDoc(QString in);
 	void PutPage(QString in);
 	void StartObj(int nr);
+	void WritePDFStream(QString cc);
 	QString CompressStr(QString *in);
+	QString PDFEncode(QString in);
 	void PDF_Bookmark(int nr, float ypos);
-	void PDF_Annotation(int Typ, int Ziel, QString Act, QString text, float x, float y, float x2, float y2);
+	void PDF_Annotation(PageItem *ite, uint PNr);
 	void PDF_circle(float x, float y);
 	void PDF_roundRect(float b, float h, float r);
+	void PDF_Form(QString im);
+  void PDF_xForm(float w, float h, QString im);
 	QString ImageToTxt(QImage *im);
 	QString MaskToTxt(QImage *im);
-	void PDF_Image(QString fn, float sx, float sy, float x, float y);
+	void PDF_Image(QString fn, float sx, float sy, float x, float y, bool fromAN = false);
 	struct Dest {	QString Name;
 								int Seite;
 								QString Act;
@@ -77,6 +84,7 @@ private:
 								QMap<QString,int> XObjects;
 								QMap<QString,int> FObjects;
 								QValueList<int> AObjects;
+								QValueList<int> FormObjects;
 							} Seite;
 	struct OutL { int First;
 								int Last;
@@ -92,6 +100,7 @@ private:
 	QValueList<Dest> NamedDest;
 	QValueList<int> Threads;
 	QValueList<Bead> Beads;
+	QValueList<int> CalcFields;
 	int ObjCounter;
 	bool NeedsStroke;
 	QString ResNam;
