@@ -5,7 +5,7 @@
 
 extern QPixmap loadIcon(QString nam);
 
-MusterSeiten::MusterSeiten( QWidget* parent, ScribusDoc *doc, ScribusView *view)
+MusterSeiten::MusterSeiten( QWidget* parent, ScribusDoc *doc, ScribusView *view, QString temp)
     : QDialog( parent, "Muster", false, WDestructiveClose)
 {
     setCaption( tr( "Edit Templates" ) );
@@ -47,9 +47,18 @@ MusterSeiten::MusterSeiten( QWidget* parent, ScribusDoc *doc, ScribusView *view)
     ExitB->setText( tr( "Exit" ) );
     Layout2->addWidget( ExitB );
     MusterSeitenLayout->addLayout( Layout2 );
-    sMuster = "Normal";
-    updateMList(sMuster);
-    View->ShowTemplate(0);
+		if (temp == "")
+			{
+    	sMuster = "Normal";
+    	updateMList(sMuster);
+    	View->ShowTemplate(0);
+			}
+		else
+			{
+    	sMuster = temp;
+    	updateMList(sMuster);
+    	View->ShowTemplate(View->MasterNames[sMuster]);
+			}
     setMaximumSize(sizeHint());
 
     // signals and slots connections
@@ -94,6 +103,7 @@ void MusterSeiten::DelTemp()
   	{
 		Doc->PageC = View->Pages.count();
 		View->delPage(View->MasterNames[sMuster]);
+		View->reformPages();
 		View->MasterNames.clear();
 		for (uint a=0; a<View->Pages.count(); a++)
 			{
