@@ -11,7 +11,7 @@ PDF_Opts::PDF_Opts( QWidget* parent,  QString Fname, QMap<QString,QFont> DocFont
   	FontsToEmbed.clear();
   	view = vie;
   	EffVal = Eff;
-    PDFOptsLayout = new QVBoxLayout( this );
+  	PDFOptsLayout = new QVBoxLayout( this );
     PDFOptsLayout->setSpacing( 6 );
     PDFOptsLayout->setMargin( 11 );
     Name = new QLabel( this, "Name" );
@@ -36,6 +36,43 @@ PDF_Opts::PDF_Opts( QWidget* parent,  QString Fname, QMap<QString,QFont> DocFont
     tabLayout = new QVBoxLayout( tab );
     tabLayout->setSpacing( 6 );
     tabLayout->setMargin( 11 );
+
+    Layout13 = new QHBoxLayout( 0, 0, 6, "Layout13");
+
+    RangeGroup = new QButtonGroup( tab, "RangeGroup" );
+    RangeGroup->setTitle( tr( "Export Range" ) );
+    RangeGroup->setColumnLayout(0, Qt::Vertical );
+    RangeGroup->layout()->setSpacing( 6 );
+    RangeGroup->layout()->setMargin( 11 );
+    RangeGroupLayout = new QVBoxLayout( RangeGroup->layout() );
+    RangeGroupLayout->setAlignment( Qt::AlignTop );
+    AllPages = new QRadioButton( RangeGroup, "AllPages" );
+    AllPages->setText( tr( "All Pages" ) );
+    AllPages->setChecked( TRUE );
+    RangeGroupLayout->addWidget( AllPages );
+    Layout11 = new QGridLayout( 0, 1, 1, 0, 6, "Layout11");
+    OnlySome = new QRadioButton( RangeGroup, "OnlySome" );
+    OnlySome->setText( tr( "From:" ) );
+    Layout11->addWidget( OnlySome, 0, 0 );
+    LastPage = new QSpinBox( RangeGroup, "LastPage" );
+    LastPage->setMaxValue(view->Pages.count());
+    LastPage->setMinValue( 1 );
+    Layout11->addWidget( LastPage, 1, 1 );
+    RText = new QLabel( RangeGroup, "RText" );
+    RText->setText( tr( "to:" ) );
+    Layout11->addWidget( RText, 1, 0, AlignRight );
+    FirstPage = new QSpinBox( RangeGroup, "FirstPage" );
+    FirstPage->setMaxValue(view->Pages.count());
+    FirstPage->setMinValue( 1 );
+		FirstPage->setValue(1);
+		LastPage->setValue(view->Pages.count());
+    Layout11->addWidget( FirstPage, 0, 1 );
+    RangeGroupLayout->addLayout( Layout11 );
+		FirstPage->setEnabled(false);
+		LastPage->setEnabled(false);
+		RText->setEnabled(false);
+    Layout13->addWidget( RangeGroup );
+
     GroupBox1 = new QGroupBox( tab, "GroupBox1" );
     GroupBox1->setTitle( tr( "File Options" ) );
     GroupBox1->setColumnLayout(0, Qt::Vertical );
@@ -65,10 +102,10 @@ PDF_Opts::PDF_Opts( QWidget* parent,  QString Fname, QMap<QString,QFont> DocFont
     GroupBox1Layout->addMultiCellWidget( ComboBind, 1, 1, 1, 2, AlignLeft );
     CheckBox1 = new QCheckBox( GroupBox1, "CheckBox1" );
     CheckBox1->setText( tr( "Generate Thumbnails" ) );
-    GroupBox1Layout->addMultiCellWidget( CheckBox1, 2, 2, 1, 2 );
+    GroupBox1Layout->addMultiCellWidget( CheckBox1, 2, 2, 0, 2 );
     Article = new QCheckBox( GroupBox1, "CheckBox1" );
-    Article->setText( tr( "Save linked Textframes as PDF-Articles" ) );
-    GroupBox1Layout->addMultiCellWidget( Article, 3, 3, 1, 2 );
+    Article->setText( tr( "Save linked Text Frames as PDF-Articles" ) );
+    GroupBox1Layout->addMultiCellWidget( Article, 3, 3, 0, 2 );
     TextLabel2 = new QLabel( GroupBox1, "TextLabel2" );
     TextLabel2->setText( tr( "Resolution:" ) );
     TextLabel2->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignLeft ) );
@@ -79,7 +116,8 @@ PDF_Opts::PDF_Opts( QWidget* parent,  QString Fname, QMap<QString,QFont> DocFont
     Resolution->setValue( 300 );
     Resolution->setSuffix( tr( " dpi" ) );
     GroupBox1Layout->addWidget( Resolution, 4, 1, AlignLeft );
-    tabLayout->addWidget( GroupBox1 );
+    Layout13->addWidget( GroupBox1 );
+    tabLayout->addLayout( Layout13 );
     GroupBox2 = new QGroupBox( tab, "GroupBox2" );
     GroupBox2->setTitle( tr( "Compression" ) );
     GroupBox2->setColumnLayout(0, Qt::Vertical );
@@ -100,7 +138,7 @@ PDF_Opts::PDF_Opts( QWidget* parent,  QString Fname, QMap<QString,QFont> DocFont
     ValC->setEnabled(false);
     GroupBox2Layout->addWidget( ValC, 1, 1, AlignLeft );
     Compression = new QCheckBox( GroupBox2, "Compression" );
-    Compression->setText( tr( "Compress Text and Vectorgraphics" ) );
+    Compression->setText( tr( "Compress Text and Vector Graphics" ) );
     Compression->setChecked( TRUE );
     GroupBox2Layout->addMultiCellWidget( Compression, 0, 0, 0, 1 );
     tabLayout->addWidget( GroupBox2 );
@@ -278,6 +316,9 @@ PDF_Opts::PDF_Opts( QWidget* parent,  QString Fname, QMap<QString,QFont> DocFont
     EDirection_2_2->insertItem( tr( "Top-Left to Bottom-Right" ) );
     EDirection_2_2->setEditable(false);
 		EffectsLayout->addWidget( EDirection_2_2, 5, 1 );
+		EonAllPg = new QPushButton( Effects, "Eon" );
+    EonAllPg->setText( tr( "Apply Effect on all Pages" ) );
+		EffectsLayout->addMultiCellWidget( EonAllPg, 6, 6, 0, 1 );
     tabLayout_5->addMultiCellWidget( Effects, 1, 2, 1, 1 );
     Options->insertTab( tab_5, tr( "Extras" ) );
     PgSel = 0;
@@ -292,18 +333,16 @@ PDF_Opts::PDF_Opts( QWidget* parent,  QString Fname, QMap<QString,QFont> DocFont
     Layout7->setMargin( 0 );
     QSpacerItem* spacer_2 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
     Layout7->addItem( spacer_2 );
-    Cancel = new QPushButton( this, "Cancel" );
-    Cancel->setMinimumSize( QSize( 120, 30 ) );
-    Cancel->setText( tr( "Cancel" ) );
-    Layout7->addWidget( Cancel );
-    QSpacerItem* spacer_3 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
-    Layout7->addItem( spacer_3 );
     OK = new QPushButton( this, "OK" );
-    OK->setMinimumSize( QSize( 120, 30 ) );
     OK->setText( tr( "OK" ) );
     OK->setAutoDefault( TRUE );
     OK->setDefault( TRUE );
     Layout7->addWidget( OK );
+    QSpacerItem* spacer_3 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
+    Layout7->addItem( spacer_3 );
+    Cancel = new QPushButton( this, "Cancel" );
+    Cancel->setText( tr( "Cancel" ) );
+    Layout7->addWidget( Cancel );
     QSpacerItem* spacer_4 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
     Layout7->addItem( spacer_4 );
     PDFOptsLayout->addLayout( Layout7 );
@@ -322,9 +361,13 @@ PDF_Opts::PDF_Opts( QWidget* parent,  QString Fname, QMap<QString,QFont> DocFont
     connect(CheckBM, SIGNAL(clicked()), this, SLOT(ToggleBM()));
     connect(PagePrev, SIGNAL(clicked()), this, SLOT(PagePr()));
     connect(Pages, SIGNAL(highlighted(int)), this, SLOT(SetPgEff(int)));
-    connect(EffectType, SIGNAL(highlighted(int)), this, SLOT(SetEffOpts(int)));
+    connect(EffectType, SIGNAL(activated(int)), this, SLOT(SetEffOpts(int)));
     connect(EDirection_2_2, SIGNAL(activated(int)), this, SLOT(ValidDI(int)));
     connect(CheckBox10, SIGNAL(clicked()), this, SLOT(DoEffects()));
+    connect(EonAllPg, SIGNAL(clicked()), this, SLOT(EffectOnAll()));
+    connect(AllPages, SIGNAL(toggled(bool)), this, SLOT(SelRange(bool)));
+    connect(FirstPage, SIGNAL(valueChanged(int)), this, SLOT(ChFrom()));
+    connect(LastPage, SIGNAL(valueChanged(int)), this, SLOT(ChTo()));
 }
 
 /*  
@@ -335,6 +378,53 @@ PDF_Opts::~PDF_Opts()
     // no need to delete child widgets, Qt does it all for us
 }
 
+void PDF_Opts::ChFrom()
+{
+  disconnect(LastPage, SIGNAL(valueChanged(int)), this, SLOT(ChTo()));
+	if (FirstPage->value() > LastPage->value())
+		LastPage->setValue(FirstPage->value());
+	connect(LastPage, SIGNAL(valueChanged(int)), this, SLOT(ChTo()));
+}
+
+void PDF_Opts::ChTo()
+{
+  disconnect(FirstPage, SIGNAL(valueChanged(int)), this, SLOT(ChFrom()));
+	if (LastPage->value() < FirstPage->value())
+		FirstPage->setValue(LastPage->value());
+  connect(FirstPage, SIGNAL(valueChanged(int)), this, SLOT(ChFrom()));
+}
+
+void PDF_Opts::SelRange(bool e)
+{
+	if (e)
+		{
+    RText->setEnabled( FALSE );
+    FirstPage->setEnabled( FALSE );
+   	LastPage->setEnabled( FALSE );
+		}
+	else
+		{
+    RText->setEnabled( true );
+    FirstPage->setEnabled( true );
+   	LastPage->setEnabled( true );
+		CheckBM->setChecked(false);
+		ToggleBM();
+		}
+}
+
+void PDF_Opts::EffectOnAll()
+{
+	for (uint pg = 0; pg < view->Pages.count(); pg++)
+		{
+		EffVal[pg].AnzeigeLen = PageTime->value();
+		EffVal[pg].EffektLen = EffectTime->value();
+		EffVal[pg].Effekt = EffectType->currentItem();
+		EffVal[pg].Dm = EDirection->currentItem();
+		EffVal[pg].M = EDirection_2->currentItem();
+		EffVal[pg].Di = EDirection_2_2->currentItem();
+		}
+}
+
 void PDF_Opts::DoEffects()
 {
 	if (CheckBox10->isChecked())
@@ -354,7 +444,7 @@ void PDF_Opts::DoEffects()
 void PDF_Opts::ValidDI(int nr)
 {
 	if (!EDirection_2_2->listBox()->item(nr)->isSelectable())
-		EDirection_2_2->setCurrentItem(0);	
+		EDirection_2_2->setCurrentItem(0);
 }
 
 void PDF_Opts::SetPgEff(int nr)
@@ -366,7 +456,7 @@ void PDF_Opts::SetPgEff(int nr)
 	EffVal[PgSel].Effekt = EffectType->currentItem();
 	EffVal[PgSel].Dm = EDirection->currentItem();
 	EffVal[PgSel].M = EDirection_2->currentItem();
-	EffVal[PgSel].Di = EDirection_2->currentItem();
+	EffVal[PgSel].Di = EDirection_2_2->currentItem();
 	SetEffOpts(EffectType->currentItem());
 	PageTime->setValue(EffVal[nr].AnzeigeLen);
 	EffectTime->setValue(EffVal[nr].EffektLen);
@@ -540,7 +630,7 @@ void PDF_Opts::EmbedAll()
 void PDF_Opts::ChangeFile()
 {
 	QString fn;
-	CustomFDialog dia(this, tr("Save as"), tr("PDF-Files (*.pdf);; All Files (*)"));
+	CustomFDialog dia(this, tr("Save as"), tr("PDF-Files (*.pdf);; All Files (*)"), false, false);
 	if (Datei->text() != "")
 		dia.setSelection(Datei->text());
 	if (dia.exec())
