@@ -10,7 +10,7 @@
 #include <qwhatsthis.h>
 #include <qcheckbox.h>
 #include <qheader.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qvaluelist.h>
 #include "scribusdoc.h"
 #include "scribusview.h"
@@ -30,7 +30,7 @@ public:
     ScribusDoc *doc;
     ScribusView *view;
     int Zeilen;
-    QList<QCheckBox> FlagsPic;
+    QPtrList<QCheckBox> FlagsPic;
     QValueList<uint> ItemNrs;
 
 private slots:
