@@ -202,7 +202,7 @@ bool sc_TTFont::ReadMetrics(float *charwidths)
 		}
 
 		float ndw=Hmtx[0].advanceWidth+Hmtx[0].lsb;
-		ndw/=Head.unitsPerEm;
+		ndw/=float(Head.unitsPerEm);
 
 		for(int i=0; i<256; ++i)
 		{
@@ -215,7 +215,7 @@ bool sc_TTFont::ReadMetrics(float *charwidths)
 					if(gn>=Hhea.numberOfHMetrics)
 						gn=Hhea.numberOfHMetrics-1;
 					float cw=Hmtx[gn].advanceWidth+Hmtx[gn].lsb;
-					charwidths[i]=cw/Head.unitsPerEm;
+					charwidths[i]=cw/float(Head.unitsPerEm);
 				}
 				else
 					charwidths[i]=ndw;
