@@ -27,6 +27,7 @@
 #include <qstringlist.h>
 #include <qimage.h>
 #include <qcstring.h>
+extern void Level2Layer(ScribusDoc *doc, struct Layer *ll, int Level);
 
 ScribusView::ScribusView(QWidget *parent, ScribusDoc *doc, preV *prefs)
  						: QScrollView(parent, "s", WRepaintNoErase | WNorthWestGravity)
@@ -40,6 +41,7 @@ ScribusView::ScribusView(QWidget *parent, ScribusDoc *doc, preV *prefs)
 	setMargins(25, 25, 0, 0);
 	setResizePolicy(Manual);
 	enableClipper(TRUE);
+  viewport()->setBackgroundMode(PaletteBackground);
 	QFont fo = QFont(font());
 	fo.setPointSize(10);
 	LE = new QLineEdit(this);
@@ -59,19 +61,39 @@ ScribusView::ScribusView(QWidget *parent, ScribusDoc *doc, preV *prefs)
 	LA->setText(tr("Page")+" 1");
 	LA->setPopup(Seitmen);
 	LA->setFocusPolicy(QWidget::NoFocus);
+	LY = new QPushButton(this);
+	LY->setFont(fo);
+	Laymen = new QPopupMenu(this);
+	Laymen->setFont(fo);
+	LY->setText(tr("Layer")+" 0");
+	LY->setPopup(Laymen);
+	LY->setFocusPolicy(QWidget::NoFocus);
 	HR = new Hruler(this, Doc);
 	VR = new Vruler(this, Doc);
 	UN = new QToolButton(this);
 	Unitmen = new QPopupMenu(this);
 	Unitmen->insertItem("pt");
 	Unitmen->insertItem("mm");
+	Unitmen->insertItem("in");
+	Unitmen->insertItem("p");
 	UN->setPopup(Unitmen);
 	UN->setFocusPolicy(QWidget::NoFocus);
 	UN->setPopupDelay(10);
-	if (doc->Einheit == 0)
-		UN->setText("pt");
-	else
-		UN->setText("mm");
+	switch (doc->Einheit)
+		{
+		case 0:
+			UN->setText("pt");
+			break;
+		case 1:
+			UN->setText("mm");
+			break;
+		case 2:
+			UN->setText("in");
+			break;
+		case 3:
+			UN->setText("p");
+			break;
+		}
 	Pages.clear();
 	MasterPages.clear();
 	DocPages.clear();
@@ -80,6 +102,7 @@ ScribusView::ScribusView(QWidget *parent, ScribusDoc *doc, preV *prefs)
 	connect(SB2, SIGNAL(clicked()), this, SLOT(slotZoomIn()));
 	connect(LE, SIGNAL(returnPressed()), this, SLOT(Zval()));
 	connect(Seitmen, SIGNAL(activated(int)), this, SLOT(GotoPa(int)));
+	connect(Laymen, SIGNAL(activated(int)), this, SLOT(GotoLa(int)));
 	connect(Unitmen, SIGNAL(activated(int)), this, SLOT(ChgUnit(int)));
 	connect(this, SIGNAL(contentsMoving(int, int)), this, SLOT(setRulerPos(int, int)));
 }
@@ -91,13 +114,14 @@ ScribusView::~ScribusView()
 /** Waagrechter Scrollbalken */
 void ScribusView::setHBarGeometry(QScrollBar &bar, int x, int y, int w, int h)
 {
-	bar.setGeometry(x+160, y, w-160, h);
+	bar.setGeometry(x+270, y, w-270, h);
 	if (Ready)
 		{
 		LE->setGeometry(x, y, 60, h);
 		SB1->setGeometry(x+60, y, 15, h);
 		SB2->setGeometry(x+75, y, 15, h);
 		LA->setGeometry(x+90, y, 70, h);
+		LY->setGeometry(x+160, y, 110, h);
 		HR->setGeometry(25, 1, w-24, 25);
 		}
 }
@@ -174,6 +198,7 @@ Page* ScribusView::addPage(int nr)
 				else
 					Doc->FirstAuto = fe->Items.at(z);
 				Doc->LastAuto = fe->Items.at(z);
+				fe->SetRectFrame(fe->Items.at(z));
 				}
 			}
 		else
@@ -190,6 +215,7 @@ Page* ScribusView::addPage(int nr)
 			else
 				Doc->FirstAuto = fe->Items.at(z);
 			Doc->LastAuto = fe->Items.at(z);
+			fe->SetRectFrame(fe->Items.at(z));
 			}
 		Doc->FirstAuto->Dirty = true;
 		Doc->FirstAuto->paintObj();
@@ -203,41 +229,28 @@ Page* ScribusView::addPage(int nr)
 	connect(fe, SIGNAL(ZoomOut()), this, SLOT(slotZoomOut2()));
 	connect(fe, SIGNAL(ZoomAbs()), this, SLOT(slotDoZoom()));
 	connect(fe, SIGNAL(AbsPosi(int, int)), this, SLOT(SetCPo(int, int)));
+	connect(fe, SIGNAL(AbsPosi2(int, int)), this, SLOT(SetCCPo(int, int)));
 	return fe;	
 }
 
 /** Lscht eine Seite */
 void ScribusView::delPage(int Nr)
 {
-	uint a, c;
 	if (Doc->PageC == 1)
 		{ return; }
 	if (Doc->PageC < Nr-1)
 		{ return; }
-	c = Pages.at(Nr)->Items.count();
-	for (a = 0; a < c; a++)
-		{
-		Doc->ActPage = Pages.at(Nr);
-		Pages.at(Nr)->SelItem.clear();
-		Pages.at(Nr)->SelItem.append(&Pages.at(Nr)->Items.at(0)->ItemNr);
-		Pages.at(Nr)->DeleteItem();		
-		}
-	if (Nr > 0)
-		Doc->ActPage = Pages.at(0);
-	else
-		Doc->ActPage = Pages.at(1);
 	removeChild(Pages.at(Nr)->parentWidget());
 	delete Pages.at(Nr)->parentWidget();
 	Pages.remove(Nr);
 	Doc->PageC -= 1;
 	Doc->ActPage = Pages.at(0);
-	reformPages();
 	LA->setText(tr("Page")+" 1");
 }
 
 void ScribusView::movePage(int from, int to, int ziel, int art)
 {
-	QList<Page> Buf;
+	QPtrList<Page> Buf;
 	int a;
 	uint b;
 	int zz = ziel;
@@ -385,6 +398,7 @@ void ScribusView::reformPages()
 		}
 	setRulerPos(contentsX(), contentsY());
  	PaMenu();
+	setMenTxt(Doc->ActPage->PageNr);
 }	
 
 void ScribusView::setMenTxt(int Seite)
@@ -392,6 +406,11 @@ void ScribusView::setMenTxt(int Seite)
 	LA->setText(tr("Page")+" "+QString::number(Seite+1));
 }
 
+void ScribusView::setLayMenTxt(int l)
+{
+	LY->setText(Doc->Layers[l].Name);
+}
+
 /** Fhrt die Vergrerung/Verkleinerung aus */
 void ScribusView::slotDoZoom()
 { 	
@@ -455,9 +474,20 @@ void ScribusView::slotDoZoom()
 			}
 		LE->setText(QString::number(double(Doc->Scale*100), 'f', 2)+" %");
 		setRulerPos(contentsX(), contentsY());
+		if (Doc->ActPage->SelItem.count() != 0)
+			{
+			PageItem *b = Doc->ActPage->SelItem.at(0);
+			SetCCPo(int(b->Xpos + b->Width/2), int(b->Ypos + b->Height/2));
+			}
 		}
 }
 
+void ScribusView::SetCCPo(int x, int y)
+{
+	center(childX(Doc->ActPage->parentWidget())+x*Doc->Scale, childY(Doc->ActPage->parentWidget())+y*Doc->Scale);
+	setRulerPos(contentsX(), contentsY());	
+}
+
 void ScribusView::SetCPo(int x, int y)
 {
 	setContentsPos(childX(Doc->ActPage->parentWidget())+x*Doc->Scale, childY(Doc->ActPage->parentWidget())+y*Doc->Scale);
@@ -477,6 +507,27 @@ void ScribusView::PaMenu()
 		}
 }
 
+void ScribusView::LaMenu()
+{
+	uint a;
+	Laymen->clear();
+	if (Doc->Layers.count() != 0)
+		{
+		for (a=0; a < Doc->Layers.count(); a++)
+			{
+			Laymen->insertItem(Doc->Layers[a].Name);
+			}
+		}
+}
+
+void ScribusView::GotoLa(int l)
+{
+	int d = Laymen->indexOf(l);
+	Doc->ActiveLayer = d;
+	LY->setText(Doc->Layers[d].Name);
+	emit changeLA(d);
+}
+
 void ScribusView::GotoPa(int Seite)
 {
 	int d = Seitmen->indexOf(Seite);
@@ -545,7 +596,7 @@ void ScribusView::DrawNew()
 		for (a=0; a < Pages.count(); a++)
 			{
 			Doc->ActPage = Pages.at(a);
-			Pages.at(a)->setBackgroundColor(Doc->papColor);
+			Pages.at(a)->setEraseColor(Doc->papColor);
 			Pages.at(a)->update();
 			}
 		}
@@ -563,7 +614,7 @@ int ScribusView::CountElements()
 	return cc;
 }
 
-void ScribusView::RecalcPictures(ProfilesL *Pr, QProgressDialog *dia)
+void ScribusView::RecalcPictures(ProfilesL *Pr, QProgressBar *dia)
 { 	
 	uint a, i;
 	Page *b = Doc->ActPage;
@@ -642,17 +693,95 @@ void ScribusView::HideTemplate()
 	slotDoZoom();
 }
 
+QPixmap ScribusView::MPageToPixmap(QString name, int maxGr)
+{
+	QPixmap pm = QPixmap(Doc->PageB, Doc->PageH);
+	pm.fill();
+	float sca = Doc->Scale;
+	bool frs = Doc->ShFrames;
+	int Lnr;
+	struct Layer ll;
+	ll.Drucken = false;
+	ll.LNr = 0;
+	Doc->ShFrames = false;
+	Doc->Scale = 1;
+	PageItem *b;
+	PageItem *bb;
+	PageItem *nb;
+	Lnr = 0;
+	Page* Mp = MasterPages.at(MasterNames[name]);
+	QWidget* Opa;
+	Page* Opa2;
+	if (Mp->Items.count() != 0)
+		{
+		Lnr = 0;
+		for (uint la = 0; la < Doc->Layers.count(); la++)
+			{
+			Level2Layer(Doc, &ll, Lnr);
+			if (ll.Drucken)
+				{
+				for (uint a = 0; a < Mp->Items.count(); a++)
+					{
+					b = Mp->Items.at(a);
+					if (b->LayerNr != ll.LNr)
+						continue;
+					Opa = b->Parent;
+					Opa2 = b->OwnPage;
+					b->Parent = Mp;
+					b->OwnPage = Mp;
+					b->toPixmap = true;
+					nb = b->NextBox;
+					bb = b->BackBox;
+					b->NextBox = 0;
+					b->BackBox = 0;
+					b->paintObj(QRect(QRect(0, 0, Doc->PageB, Doc->PageH)), &pm);
+					b->toPixmap = false;
+					b->NextBox = nb;
+					b->BackBox = bb;
+					b->Parent = Opa;
+					b->OwnPage = Opa2;
+					}
+				}
+			Lnr++;
+			}
+		}
+	Doc->ShFrames = frs;
+	Doc->Scale = sca;
+	QImage im2;
+	QImage im = pm.convertToImage();
+	float sx = im.width() / float(maxGr);
+	float sy = im.height() / float(maxGr);
+	if (sy < sx)
+		im2 = im.smoothScale(im.width() / sx, im.height() / sx);
+	else
+		im2 = im.smoothScale(im.width() / sy, im.height() / sy);
+	pm.convertFromImage(im2);
+	QPainter p;
+	p.begin(&pm);
+	p.setBrush(NoBrush);
+	p.setPen(black);
+	p.drawRect(0, 0, pm.width(), pm.height());
+	p.end();
+	im2.detach();
+	return pm;
+}
+
 QPixmap ScribusView::PageToPixmap(int Nr, int maxGr)
 {
 	QPixmap pm = QPixmap(Doc->PageB, Doc->PageH);
 	pm.fill();
 	float sca = Doc->Scale;
 	bool frs = Doc->ShFrames;
+	int Lnr;
+	struct Layer ll;
+	ll.Drucken = false;
+	ll.LNr = 0;
 	Doc->ShFrames = false;
 	Doc->Scale = 1;
 	PageItem *b;
 	PageItem *bb;
 	PageItem *nb;
+	Lnr = 0;
 	if (Pages.at(Nr)->MPageNam != "")
 		{
 		Page* Mp = MasterPages.at(MasterNames[Pages.at(Nr)->MPageNam]);
@@ -660,42 +789,66 @@ QPixmap ScribusView::PageToPixmap(int Nr, int maxGr)
 		Page* Opa2;
 		if (Mp->Items.count() != 0)
 			{
-			for (uint a = 0; a < Mp->Items.count(); a++)
+			Lnr = 0;
+			for (uint la = 0; la < Doc->Layers.count(); la++)
 				{
-				b = Mp->Items.at(a);
-				Opa = b->Parent;
-				Opa2 = b->OwnPage;
-				b->Parent = Pages.at(Nr);
-				b->OwnPage = Pages.at(Nr);
-				b->toPixmap = true;
-				nb = b->NextBox;
-				bb = b->BackBox;
-				b->NextBox = 0;
-				b->BackBox = 0;
-				b->paintObj(QRect(), &pm);
-				b->toPixmap = false;
-				b->NextBox = nb;
-				b->BackBox = bb;
-				b->Parent = Opa;
-				b->OwnPage = Opa2;
+				Level2Layer(Doc, &ll, Lnr);
+				if (ll.Drucken)
+					{
+					for (uint a = 0; a < Mp->Items.count(); a++)
+						{
+						b = Mp->Items.at(a);
+						if (b->LayerNr != ll.LNr)
+							continue;
+						Opa = b->Parent;
+						Opa2 = b->OwnPage;
+						b->Parent = Pages.at(Nr);
+						b->OwnPage = Pages.at(Nr);
+						b->toPixmap = true;
+						nb = b->NextBox;
+						bb = b->BackBox;
+						b->NextBox = 0;
+						b->BackBox = 0;
+						b->paintObj(QRect(QRect(0, 0, Doc->PageB, Doc->PageH)), &pm);
+						b->toPixmap = false;
+						b->NextBox = nb;
+						b->BackBox = bb;
+						b->Parent = Opa;
+						b->OwnPage = Opa2;
+						}
+					}
+				Lnr++;
 				}
 			}
 		}
-	for (uint a = 0; a < Pages.at(Nr)->Items.count(); a++)
+	Lnr = 0;
+	for (uint la2 = 0; la2 < Doc->Layers.count(); la2++)
 		{
-		b = Pages.at(Nr)->Items.at(a);
-		if ((b->isPrintable) && (!b->isAnnotation))
+		Level2Layer(Doc, &ll, Lnr);
+		if (ll.Drucken)
 			{
-			b->toPixmap = true;
-			nb = b->NextBox;
-			bb = b->BackBox;
-			b->NextBox = 0;
-			b->BackBox = 0;
-			b->paintObj(QRect(), &pm);
-			b->toPixmap = false;
-			b->NextBox = nb;
-			b->BackBox = bb;
+			for (uint a = 0; a < Pages.at(Nr)->Items.count(); a++)
+				{
+				b = Pages.at(Nr)->Items.at(a);
+				if (b->LayerNr != ll.LNr)
+					continue;
+				if (b->isPrintable)
+					{
+					if ((b->isAnnotation) && (b->AnType != 2))
+						continue;
+					b->toPixmap = true;
+					nb = b->NextBox;
+					bb = b->BackBox;
+					b->NextBox = 0;
+					b->BackBox = 0;
+					b->paintObj(QRect(), &pm);
+					b->toPixmap = false;
+					b->NextBox = nb;
+					b->BackBox = bb;
+					}
+				}
 			}
+		Lnr++;
 		}
 	Doc->ShFrames = frs;
 	Doc->Scale = sca;
@@ -730,7 +883,7 @@ QString ScribusView::CreatePS(PSLib *p, uint von, uint bis, int step, bool sep,
 	sepac = 0;
 	while (a != bis)
 		{
-		p->PS_begin_page(Doc->PageB, Doc->PageH, &Pages.at(a)->Margins);
+		p->PS_begin_page(Doc->PageOri, Doc->PageB, Doc->PageH, &Pages.at(a)->Margins);
 		if (sep)
 			{
 			if (SepNam == "Black")
@@ -774,285 +927,345 @@ void ScribusView::ProcessPage(PSLib *p, Page* a, uint PNr)
 	uint b, d;
 	int h, s, v, k, tsz;
 	QCString chxc;
-	CMYKColor tmp;
 	QString chx;
 	PageItem *c;
 	struct Pti *hl;
-	QPoint np;
 	bool needsStroke = false;
-		for (b = 0; b < a->Items.count(); b++)
+	int Lnr = 0;
+	struct Layer ll;
+	ll.Drucken = false;
+	ll.LNr = 0;
+	for (uint la = 0; la < Doc->Layers.count(); la++)
+		{
+		Level2Layer(Doc, &ll, Lnr);
+		if (ll.Drucken)
 			{
-			c = a->Items.at(b);
-			if (c->isPrintable)
+			for (b = 0; b < a->Items.count(); b++)
 				{
-				p->PS_save();
-				if (c->Pcolor != "None")
+				c = a->Items.at(b);
+				if (c->LayerNr != ll.LNr)
+					continue;
+				if (c->isPrintable)
 					{
-					tmp = Doc->PageColors[c->Pcolor];
-					tmp.applyGCR();
-					tmp.getCMYK(&h, &s, &v, &k);
-					h = h * c->Shade / 100;
-					s = s * c->Shade / 100;
-					v = v * c->Shade / 100;
-					k = k * c->Shade / 100;
-					p->PS_setcmykcolor_fill(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
-					}
-				if (c->Pcolor2 != "None")
-					{
-					tmp = Doc->PageColors[c->Pcolor2];
-					tmp.applyGCR();
-					tmp.getCMYK(&h, &s, &v, &k);
-					h = h * c->Shade2 / 100;
-					s = s * c->Shade2 / 100;
-					v = v * c->Shade2 / 100;
-					k = k * c->Shade2 / 100;
-					p->PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
-					}
-				p->PS_setlinewidth(QMAX(c->Pwidth, 1));
-				p->PS_setdash(c->PLineArt, c->PLineEnd, c->PLineJoin);
-				p->PS_translate(c->Xpos, Doc->PageH - c->Ypos);
-				if (c->Rot != 0)
-					{
-					p->PS_rotate(-c->Rot);
-					}
-				switch (c->PType)
-					{
-					case 1:
-						p->PS_translate(c->Width / 2, -c->Height / 2);
-						p->PS_circle(c->Width / 2, c->Height / 2);
-						needsStroke = true;
-						break;
-					case 2:
-						if ((c->flippedH % 2) != 0)
-							{
-							p->PS_translate(c->Width, 0);
-							p->PS_scale(-1, 1);
-							}
-						if ((c->flippedV % 2) != 0)
-							{
-							p->PS_translate(0, -c->Height);
-							p->PS_scale(1, -1);
-							}
-						if (c->Pcolor != "None")
-							{
-							if ((c->FrameType == 2) && (!c->ClipEdited))
-								p->PS_RoundRect(0, 0, c->Width, -c->Height, c->RadRect);
-							else
-								{	
-								d = 0;
-								np = c->Clip.point(d);
-								p->PS_moveto(np.x(), -np.y());
-								for (d = 1; d < c->Clip.count(); d++)
-									{
-									np = c->Clip.point(d);
-									p->PS_lineto(np.x(), -np.y());
-									}
-								}
-							p->PS_closepath();
-							p->PS_fill();
-							}
-						if ((c->FrameType == 2) && (!c->ClipEdited))
-							p->PS_RoundRect(0, 0, c->Width, -c->Height, c->RadRect);
-						else
-							{
-							d = 0;
-							np = c->Clip.point(d);
-							p->PS_moveto(np.x(), -np.y());
-							for (d = 1; d < c->Clip.count(); d++)
-								{
-								np = c->Clip.point(d);
-								p->PS_lineto(np.x(), -np.y());
-								}
-							}
-						p->PS_closepath();
-						p->PS_clip();
-						if ((c->PicAvail) && (c->Pfile != ""))
-							{
-							p->PS_translate(0, -c->BBoxH*c->LocalScY);
-							p->PS_image(-c->BBoxX+c->LocalX, -c->LocalY, c->Pfile, c->LocalScX, c->LocalScY);
-							}						
-						needsStroke = false;
-						break;
-					case 3:
-						if (c->RadRect != 0)
-							p->PS_RoundRect(0, 0, c->Width, -c->Height, c->RadRect);
-						else
-							p->PS_rect(0, 0, c->Width, -c->Height);
-						needsStroke = true;
-						break;
-					case 4:
-						needsStroke = false;
-						if (c->isBookmark)
-							{
-							QString bm = "";
-							QString cc;
-							for (d = 0; d < c->Ptext.count(); d++)
-								{
-								if ((c->Ptext.at(d)->ch == QChar(13)) || (c->Ptext.at(d)->ch == QChar(10)))
-									break;
-								bm += "\\"+cc.setNum(c->Ptext.at(d)->ch.at(0).unicode(), 8);
-								}
-							p->PDF_Bookmark(bm, a->PageNr+1);
-							}
-						if (c->isAnnotation)
-							{
-							QString bm = "";
-							QString cc;
-							for (d = 0; d < c->Ptext.count(); d++)
-								{
-								bm += "\\"+cc.setNum(c->Ptext.at(d)->ch.at(0).unicode(), 8);
-								}
-							p->PDF_Annotation(bm, 0, 0, c->Width, -c->Height);
+					p->PS_save();
+					if (c->Pcolor != "None")
+						{
+						SetFarbe(c->Pcolor, c->Shade, &h, &s, &v, &k);
+						p->PS_setcmykcolor_fill(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+						}
+					if (c->Pcolor2 != "None")
+						{
+						SetFarbe(c->Pcolor2, c->Shade2, &h, &s, &v, &k);
+						p->PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+						}
+					p->PS_setlinewidth(c->Pwidth);
+					p->PS_setdash(c->PLineArt, c->PLineEnd, c->PLineJoin);
+					p->PS_translate(c->Xpos, Doc->PageH - c->Ypos);
+					if (c->Rot != 0)
+						{
+						p->PS_rotate(-c->Rot);
+						}
+					switch (c->PType)
+						{
+						case 1:
+							p->PS_translate(c->Width / 2, -c->Height / 2);
+							p->PS_circle(c->Width / 2, c->Height / 2);
+							needsStroke = true;
 							break;
-							}
-						if ((c->flippedH % 2) != 0)
-							{
-							p->PS_translate(c->Width, 0);
-							p->PS_scale(-1, 1);
-							}
-						if ((c->flippedV % 2) != 0)
-							{
-							p->PS_translate(0, -c->Height);
-							p->PS_scale(1, -1);
-							}
-						if (c->Pcolor != "None")
-							{
+						case 2:
+							if (c->Pcolor != "None")
+								{
+								if ((c->FrameType == 2) && (!c->ClipEdited))
+									p->PS_RoundRect(0, 0, c->Width, -c->Height, c->RadRect);
+								else
+									SetClipPath(p, c);
+								p->PS_closepath();
+								p->PS_fill();
+								}
 							if ((c->FrameType == 2) && (!c->ClipEdited))
 								p->PS_RoundRect(0, 0, c->Width, -c->Height, c->RadRect);
 							else
-								{
-								d = 0;
-								np = c->Clip.point(d);
-								p->PS_moveto(np.x(), -np.y());
-								for (d = 1; d < c->Clip.count(); d++)
-									{
-									np = c->Clip.point(d);
-									p->PS_lineto(np.x(), -np.y());
-									}
-								}
+								SetClipPath(p, c);
 							p->PS_closepath();
-							p->PS_fill();
-							}
-						for (d = 0; d < c->MaxChars; d++)
-							{
-							hl = c->Ptext.at(d);
-							if ((hl->ch == QChar(13)) || (hl->ch == QChar(10))) // || (hl->ch == QChar(32)))
-								continue;
-							if (hl->yp == 0)
-								break;
-							tsz = hl->csize;
-							chx = hl->ch;
-							if (hl->ch == QChar(30))
+							p->PS_clip();
+							if ((c->flippedH % 2) != 0)
 								{
-								if (Doc->MasterP)
-									chx = "#";
+								p->PS_translate(c->Width, 0);
+								p->PS_scale(-1, 1);
+								}
+							if ((c->flippedV % 2) != 0)
+								{
+								p->PS_translate(0, -c->Height);
+								p->PS_scale(1, -1);
+								}
+							if ((c->PicAvail) && (c->Pfile != ""))
+								{
+								p->PS_translate(0, -c->BBoxH*c->LocalScY);
+								p->PS_image(-c->BBoxX+c->LocalX, -c->LocalY, c->Pfile, c->LocalScX, c->LocalScY);
+								}						
+							needsStroke = false;
+							break;
+						case 3:
+							if (c->RadRect != 0)
+								p->PS_RoundRect(0, 0, c->Width, -c->Height, c->RadRect);
+							else
+								p->PS_rect(0, 0, c->Width, -c->Height);
+							needsStroke = true;
+							break;
+						case 4:
+							needsStroke = false;
+							if (c->isBookmark)
+								{
+								QString bm = "";
+								QString cc;
+								for (d = 0; d < c->Ptext.count(); d++)
+									{
+									if ((c->Ptext.at(d)->ch == QChar(13)) || (c->Ptext.at(d)->ch == QChar(10)))
+										break;
+									bm += "\\"+cc.setNum(c->Ptext.at(d)->ch.at(0).unicode(), 8);
+									}
+								p->PDF_Bookmark(bm, a->PageNr+1);
+								}
+							if (c->isAnnotation)
+								{
+								QString bm = "";
+								QString cc;
+								for (d = 0; d < c->Ptext.count(); d++)
+									{
+									bm += "\\"+cc.setNum(c->Ptext.at(d)->ch.at(0).unicode(), 8);
+									}
+								p->PDF_Annotation(bm, 0, 0, c->Width, -c->Height);
+								break;
+								}
+							if (c->Pcolor != "None")
+								{
+								if ((c->FrameType == 2) && (!c->ClipEdited))
+									p->PS_RoundRect(0, 0, c->Width, -c->Height, c->RadRect);
+								else
+									SetClipPath(p, c);
+								p->PS_closepath();
+								p->PS_fill();
+								}
+							if ((c->flippedH % 2) != 0)
+								{
+								p->PS_translate(c->Width, 0);
+								p->PS_scale(-1, 1);
+								}
+							if ((c->flippedV % 2) != 0)
+								{
+								p->PS_translate(0, -c->Height);
+								p->PS_scale(1, -1);
+								}
+							for (d = 0; d < c->MaxChars; d++)
+								{
+								hl = c->Ptext.at(d);
+								if ((hl->ch == QChar(13)) || (hl->ch == QChar(10))) // || (hl->ch == QChar(32)))
+									continue;
+								if (hl->yp == 0)
+									break;
+								tsz = hl->csize;
+								chx = hl->ch;
+								if (hl->ch == QChar(30))
+									{
+									if (Doc->MasterP)
+										chx = "#";
+									else
+										{
+										uint zae = 0;
+										while (c->Ptext.at(d+zae)->ch == QChar(30))
+											{
+											zae++;
+											if (d+zae == c->MaxChars)
+												break;
+											}
+										QString out="%1";
+										chx = out.arg(PNr-1+Doc->FirstPnum, zae).right(zae).left(1);
+										}
+									}
+								if ((hl->cstyle & 127) == 0)
+									p->PS_selectfont(hl->cfont, hl->csize);
+								if (hl->cstyle & 64)
+									{
+									if (chx.upper() != chx)
+										{
+										tsz = hl->csize * Doc->VKapit / 100;
+										chx = chx.upper();
+										}
+									}
+								if (hl->cstyle & 1)
+									tsz = hl->csize * Doc->VHochSc / 100;
+								if (hl->cstyle & 2)
+									tsz = hl->csize * Doc->VHochSc / 100;
+								if (hl->cstyle & 4)
+									p->PS_selectfontItalic(hl->cfont, tsz);
 								else
 									{
-									uint zae = 0;
-									while (c->Ptext.at(d+zae)->ch == QChar(30))
-										{
-										zae++;
-										if (d+zae == c->MaxChars)
-											break;
-										}
-									QString out="%1";
-									chx = out.arg(PNr, zae).right(zae).left(1);
+									if ((hl->cstyle & 127) != 0)
+										p->PS_selectfont(hl->cfont, tsz);
 									}
-								}
-							if ((hl->cstyle & 127) == 0)
-								p->PS_selectfont(hl->cfont, hl->csize);
-							if (hl->cstyle & 64)
-								{
-								if (chx.upper() != chx)
+								if (hl->ccolor != "None")
 									{
-									tsz = hl->csize * Doc->VKapit / 100;
-									chx = chx.upper();
+									SetFarbe(hl->ccolor, hl->cshade, &h, &s, &v, &k);
+									p->PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+									}
+								if ((chx == "(") || (chx == ")") || (chx == "\\"))
+									chx.prepend("\\");
+							  chxc = chx.local8Bit();
+								if (hl->cstyle & 32)
+									p->PS_show_xyBold(chxc, hl->xp, -hl->yp);
+								else
+									p->PS_show_xy(chxc, hl->xp, -hl->yp);
+								if (hl->cstyle & 8)
+									p->PS_underline(chxc, hl->xp, -hl->yp);
+								if (hl->cstyle & 16)
+									p->PS_strikeout(chxc, hl->xp, -hl->yp + tsz / 3);
+								if ((hl->cstyle & 128) && (c->Ptext.at(QMIN(d+1, c->Ptext.count()-1))->yp != hl->yp))
+									p->PS_show();
+								}
+							break;
+						case 5:
+							p->PS_moveto(0, 0);
+							p->PS_lineto(c->Width, -c->Height);
+							p->PS_stroke();
+							needsStroke = false;
+							break;
+						case 6:
+							SetClipPath(p, c);
+							p->PS_closepath();
+							needsStroke = true;
+							break;
+						case 7:						
+							SetClipPath(p, c);
+							needsStroke = false;
+							p->PS_stroke();
+							break;
+						case 8:
+							if (c->PoShow)
+								{
+								if (c->PoLine.size() > 3)
+									{
+									p->PS_save();
+									SetClipPath(p, c);
+									p->PS_stroke();
+									p->PS_restore();
 									}
 								}
-							if (hl->cstyle & 1)
-								tsz = hl->csize * Doc->VHochSc / 100;
-							if (hl->cstyle & 2)
-								tsz = hl->csize * Doc->VHochSc / 100;
-							if (hl->cstyle & 4)
+							needsStroke = false;
+							for (d = 0; d < c->MaxChars; d++)
 								{
-								p->PS_selectfontItalic(hl->cfont, tsz);
+								hl = c->Ptext.at(d);
+								if ((hl->ch == QChar(13)) || (hl->ch == QChar(30))) // || (hl->ch == QChar(32)))
+									continue;
+								tsz = hl->csize;
+								chx = hl->ch;
+								if ((hl->cstyle & 127) == 0)
+									p->PS_selectfont(hl->cfont, hl->csize);
+								if (hl->cstyle & 64)
+									{
+									if (chx.upper() != chx)
+										{
+										tsz = hl->csize * Doc->VKapit / 100;
+										chx = chx.upper();
+										}
+									}
+								if (hl->cstyle & 1)
+									tsz = hl->csize * Doc->VHochSc / 100;
+								if (hl->cstyle & 2)
+									tsz = hl->csize * Doc->VHochSc / 100;
+								if (hl->cstyle & 4)
+									p->PS_selectfontItalic(hl->cfont, tsz);
+								else
+									{
+									if ((hl->cstyle & 127) != 0)
+										p->PS_selectfont(hl->cfont, tsz);
+									}
+								if (hl->ccolor != "None")
+									{
+									SetFarbe(hl->ccolor, hl->cshade, &h, &s, &v, &k);
+									p->PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+									}
+								if ((chx == "(") || (chx == ")") || (chx == "\\"))
+									chx.prepend("\\");
+							  chxc = chx.local8Bit();
+								p->PS_save();
+								p->PS_translate(hl->PtransX, -hl->PtransY);
+								p->PS_rotate(-hl->PRot);
+								if (hl->cstyle & 32)
+									p->PS_show_xyBold(chxc, hl->xp, -hl->yp);
+								else
+									p->PS_show_xy(chxc, hl->xp, -hl->yp);
+								if (hl->cstyle & 8)
+									p->PS_underline(chxc, hl->xp, -hl->yp);
+								if (hl->cstyle & 16)
+									p->PS_strikeout(chxc, hl->xp, -hl->yp + tsz / 3);
+								if ((hl->cstyle & 128) && (c->Ptext.at(QMIN(d+1, c->Ptext.count()-1))->yp != hl->yp))
+									p->PS_show();
+								p->PS_restore();
 								}
-							else
-								{
-								if ((hl->cstyle & 127) != 0)
-									p->PS_selectfont(hl->cfont, tsz);
-								}
-							if (hl->ccolor != "None")
-								{
-								tmp = Doc->PageColors[hl->ccolor];
-								tmp.applyGCR();
-								tmp.getCMYK(&h, &s, &v, &k);
-								h = h * hl->cshade / 100;
-								s = s * hl->cshade / 100;
-								v = v * hl->cshade / 100;
-								k = k * hl->cshade / 100;
-								p->PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
-								}
-							if ((chx == "(") || (chx == ")") || (chx == "\\"))
-								chx.prepend("\\");
-						  chxc = chx.local8Bit();
-							if (hl->cstyle & 32)
-								p->PS_show_xyBold(chxc, hl->xp, -hl->yp);
-							else
-								p->PS_show_xy(chxc, hl->xp, -hl->yp);
-							if (hl->cstyle & 8)
-								{
-								p->PS_underline(chxc, hl->xp, -hl->yp);
-								}
-							if (hl->cstyle & 16)
-								{
-								p->PS_strikeout(chxc, hl->xp, -hl->yp + tsz / 3);
-								}
-							if ((hl->cstyle & 128) && (c->Ptext.at(QMIN(d+1, c->Ptext.count()-1))->yp != hl->yp))
-								{
-								p->PS_show();
-								}
-							}
-						break;
-					case 5:
-						p->PS_moveto(0, 0);
-						p->PS_lineto(c->Width, -c->Height);
-						p->PS_stroke();
-						needsStroke = false;
-						break;
-					}
-				if (needsStroke)
-					{
-					if (c->Pcolor == "None")
-						{
-						p->PS_stroke();
+							break;
 						}
-					else
+					if (needsStroke)
 						{
-						if (c->Pcolor2 == "None")
-							{
-							p->PS_fill();
-							}
+						if (c->Pcolor == "None")
+							p->PS_stroke();
 						else
 							{
-							p->PS_fill_stroke();
+							if (c->Pcolor2 == "None")
+								p->PS_fill();
+							else
+								p->PS_fill_stroke();
 							}
 						}
+					p->PS_restore();
 					}
-				p->PS_restore();
 				}
 			}
+		Lnr++;
+		}
+}
+
+void ScribusView::SetFarbe(QString farb, int shade, int *h, int *s, int *v, int *k)
+{
+	int h1, s1, v1, k1;
+	h1 = *h;
+	s1 = *s;
+	v1 = *v;
+	k1 = *k;
+	CMYKColor	tmp = Doc->PageColors[farb];
+	tmp.applyGCR();
+	tmp.getCMYK(&h1, &s1, &v1, &k1);
+	*h = h1 * shade / 100;
+	*s = s1 * shade / 100;
+	*v = v1 * shade / 100;
+	*k = k1 * shade / 100;
+}
+
+void ScribusView::SetClipPath(PSLib *p, PageItem *c)
+{
+	FPoint np, np1, np2;
+	if (c->PoLine.size() > 3)
+		{
+		np = c->PoLine.point(0);
+		p->PS_moveto(np.x(), -np.y());
+		for (uint poi=0; poi<c->PoLine.size()-3; poi += 4)
+			{
+			np = c->PoLine.point(poi+1);
+			np1 = c->PoLine.point(poi+3);
+			np2 = c->PoLine.point(poi+2);
+			p->PS_curve(np.x(), -np.y(), np1.x(), -np1.y(), np2.x(), -np2.y());
+			}
+		}
 }
 
 void ScribusView::contentsWheelEvent(QWheelEvent *w)
 {
 	if (w->delta() < 0)
 		{
-			scrollBy(0, Prefs->Wheelval); // Prefs.Wheelval);
+			scrollBy(0, Prefs->Wheelval);
 		}
 	else
 		{
-		  scrollBy(0, -Prefs->Wheelval); // Prefs.Wheelval);
+		  scrollBy(0, -Prefs->Wheelval);
 		}
 	w->accept();
 }
