@@ -20,7 +20,7 @@
 
 // include files for QT
 #include <qscrollview.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qlineedit.h>
 #include <qscrollbar.h>
 #include <qpushbutton.h>
@@ -51,11 +51,11 @@ class ScribusView : public QScrollView
   QLineEdit *LE;
   QToolButton *UN;
   /** Liste der Seiten */
-  QList<Page> Pages;
+  QPtrList<Page> Pages;
   /** Liste der Musterseiten */
-  QList<Page> MasterPages;
+  QPtrList<Page> MasterPages;
   /** Liste der Dokumentseiten */
-  QList<Page> DocPages;
+  QPtrList<Page> DocPages;
   /** Mapping Namen zu Musterseiten */
   QMap<QString,int> MasterNames;
   /** Fgt eine Seite hinzu */
@@ -66,13 +66,17 @@ class ScribusView : public QScrollView
   void movePage(int from, int to, int ziel, int art);
   void reformPages();
   void PaMenu();
+	void LaMenu();
   void ShowTemplate(int nr);
   void HideTemplate();
   int CountElements();
   QPixmap PageToPixmap(int Nr, int maxGr);
-  void RecalcPictures(ProfilesL *Pr, QProgressDialog *dia = 0);
+	QPixmap MPageToPixmap(QString name, int maxGr);
+  void RecalcPictures(ProfilesL *Pr, QProgressBar *dia = 0);
   QString CreatePS(PSLib *p, uint von, uint bis, int step, bool sep, QString SepNam, bool farb);
   void ProcessPage(PSLib *p, Page* a, uint PNr);
+	void SetClipPath(PSLib *p, PageItem *c);
+	void SetFarbe(QString farb, int shade, int *h, int *s, int *v, int *k);
   /** Dokument zu dem die Seite gehrt */
   ScribusDoc *Doc;
 
@@ -90,16 +94,21 @@ public slots: // Public slots
   /** Zeichnet alle Seiten neu */
   void DrawNew();
   void setMenTxt(int Seite);
+	void setLayMenTxt(int l);
   void GotoPa(int Seite);
+	void GotoLa(int l);
   void GotoPage(int Seite);
   void ChgUnit(int art);
   void SetCPo(int x, int y);
+	void SetCCPo(int x, int y);
 private: // Private attributes
   QPushButton *SB1;
   QPushButton *SB2;
   QPushButton *LA;
+  QPushButton *LY;
   QPopupMenu *Seitmen;
   QPopupMenu *Unitmen;
+	QPopupMenu *Laymen;
   Hruler *HR;
   Vruler *VR;
   bool Ready;
@@ -114,5 +123,6 @@ protected: // Protected methods
 	virtual void setVBarGeometry(QScrollBar &bar, int x, int y, int w, int h);
 signals:
 	void changeUN(int);
+	void changeLA(int);
 };
 #endif
